import React, { useEffect, useState } from 'react';
import { Link, useParams } from 'react-router-dom';
import SearchBar from '../components/SearchBar';
import { Button, Form, Modal } from 'react-bootstrap';
import { useSelector, useDispatch } from 'react-redux';
import { fetchBrands, findCampaignById, findProductById } from '../store/slices/brandsSlice';
import CampaignInfo from '../components/CampaignInfo';
import { ChevronRight, Send, Plus } from 'lucide-react';
import ProductsList from '../components/ProductsList';
import SlidePanel from '../components/SlidePanel';
import CampaignScript from './CampaignScript';

export default function CampaignDetail() {
    const { brandId, campaignId } = useParams();
    const dispatch = useDispatch();
    const { brands, selectedBrand, selectedCampaign } = useSelector((state) => state.brands);
    const progressList = ['Find', 'Review', 'Confirmed', 'Draft Ready', 'Published'];
    const [progressIndex, setProgressIndex] = useState(2);
    const [activeTab, setActiveTab] = useState('products');
    const [showProductDetail, setShowProductDetail] = useState(false);
    const [showAddProductModal, setShowAddProductModal] = useState(false);

    useEffect(() => {
        dispatch(fetchBrands());
    }, [dispatch]);

    useEffect(() => {
        if (brandId && campaignId) {
            dispatch(findCampaignById({ brandId, campaignId }));
        }
    }, [brandId, campaignId]);

    const handleShowProductDetail = (productId) => {
        dispatch(findProductById({ brandId, campaignId, productId }));
        setShowProductDetail(true);
    };

    return (
        selectedCampaign?.id && (
            <div className='campaign-detail'>
                <div className='function-bar'>
                    <SearchBar />
                    <Button>
                        <Send size={18} />
                        Email
                    </Button>
                </div>
                <div className='breadcrumb'>
                    <Link to={'/brands'} className='breadcrumb-item'>
                        Brands
                    </Link>
                    <Link to={`/brands/${brandId}`} className='breadcrumb-item'>
                        {selectedBrand.name}
                    </Link>
                    <div className='breadcrumb-item'>{selectedCampaign.name}</div>
                </div>
                <CampaignInfo />
                <Form className='campaign-requirements shadow-xs'>
                    <Form.Group className='mb-3 additional_requirements' controlId='additional_requirements'>
                        <Form.Label>Additional Requirements</Form.Label>
                        <Form.Control type='text' placeholder='xxx' />
                    </Form.Group>
                    <Form.Group className='mb-3 creator_requirements' controlId='creator_requirements'>
                        <Form.Label>Creators</Form.Label>
                        <Form.Control type='number' />
                    </Form.Group>
                    <Button type='submit' variant='primary-subtle'>
                        Match Creators
                    </Button>
                </Form>
                <div className='campaign-progress shadow-xs'>
                    {progressList.map((item, index) =>
                        index < progressList.length - 1 ? (
                            <React.Fragment key={index}>
                                <div
                                    className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                    key={index}
                                >
                                    <div className='campaign-progress-item-index'>{index + 1}</div>
                                    <div className='campaign-progress-item-label'>{item}</div>
                                    <div className='campaign-progress-item-desc'>xx Creators</div>
                                </div>
                                <ChevronRight />
                            </React.Fragment>
                        ) : (
                            <div
                                className={`campaign-progress-item ${progressIndex === index ? 'active' : ''}`}
                                key={index}
                            >
                                <div className='campaign-progress-item-index'>{index + 1}</div>
                                <div className='campaign-progress-item-label'>{item}</div>
                                <div className='campaign-progress-item-desc'>xx Creators</div>
                            </div>
                        )
                    )}
                </div>
                <div className='campaign-tab-switches tab-switches'>
                    <div
                        className={`tab-switch-item ${activeTab === 'products' ? 'active' : ''}`}
                        onClick={() => setActiveTab('products')}
                    >
                        Products
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'accepted_creators' ? 'active' : ''}`}
                        onClick={() => setActiveTab('accepted_creators')}
                    >
                        Accepted Creators
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'matching_result' ? 'active' : ''}`}
                        onClick={() => setActiveTab('matching_result')}
                    >
                        Matching Result
                    </div>
                    <div
                        className={`tab-switch-item ${activeTab === 'email_draft' ? 'active' : ''}`}
                        onClick={() => setActiveTab('email_draft')}
                    >
                        Email Draft
                    </div>
                </div>

                {activeTab === 'products' && (
                    <>
                        <Button
                            className='add-product-btn'
                            variant='outline-primary'
                            onClick={() => setShowAddProductModal(true)}
                        >
                            <Plus size={18} />
                            Add Product
                        </Button>
                        <ProductsList onShowProductDetail={handleShowProductDetail} />
                        <SlidePanel
                            show={showProductDetail}
                            onClose={() => setShowProductDetail(false)}
                            title='Product Detail'
                            size='xxl'
                        >
                            <CampaignScript />
                        </SlidePanel>
                        <AddProductModal show={showAddProductModal} onHide={() => setShowAddProductModal(false)} />
                    </>
                )}
            </div>
        )
    );
}

function AddProductModal({ show, onHide }) {
    return (
        <Modal show={show} onHide={onHide}>
            <Modal.Header closeButton className='fw-bold'>Add Product</Modal.Header>
            <Modal.Body>
                <Form className='add-product-form'>
                    <Form.Group className='mb-3'>
                        <Form.Label>Product PID</Form.Label>
                        <Form.Select aria-label='Default select example'>
                            <option>Select</option>
                            <option value='1'>One</option>
                            <option value='2'>Two</option>
                            <option value='3'>Three</option>
                        </Form.Select>
                    </Form.Group>
                    <div className='button-group'>
                        <Button variant='outline-light' className='text-primary'>
                            Cancel
                        </Button>
                        <Button variant='primary'>Create</Button>
                    </div>
                </Form>
            </Modal.Body>
        </Modal>
    );
}
